@@ -5,15 +5,18 @@ use warnings;
 use POSIX qw(termios_h);
 use Storable;
 use Text::VisualWidth::PP 0.03 qw(vwidth);
-use Term::ReadKey qw(GetTerminalSize ReadLine);
+use Term::ReadKey qw(GetTerminalSize ReadLine ReadKey ReadMode);
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 our @EXPORT = qw( caroline );
 
 my $HISTORY_NEXT = 0;
 my $HISTORY_PREV = 1;
 
+my $IS_WIN32 = $^O eq 'MSWin32';
+require Win32::Console::ANSI if $IS_WIN32;
+
 use Class::Accessor::Lite 0.05 (
     rw => [qw(completion_callback history_max_len)],
 );
@@ -97,6 +100,10 @@ sub read_raw {
 sub enable_raw_mode {
     my $self = shift;
 
+    if ($IS_WIN32) {
+        ReadMode(5);
+        return undef;
+    }
     my $termios = POSIX::Termios->new;
     $termios->getattr(0);
     $self->{rawmode} = [$termios->getiflag, $termios->getoflag, $termios->getcflag, $termios->getlflag, $termios->getcc(VMIN), $termios->getcc(VTIME)];
@@ -112,6 +119,11 @@ sub enable_raw_mode {
 
 sub disable_raw_mode {
     my $self = shift;
+
+    if ($IS_WIN32) {
+        ReadMode(0);
+        return undef;
+    }
     if (my $r = delete $self->{rawmode}) {
         my $termios = POSIX::Termios->new;
         $termios->getattr(0);
@@ -147,10 +159,7 @@ sub edit {
     $self->debug("Columns: $state->{cols}\n");
 
     while (1) {
-        my $c;
-        if (CORE::read(STDIN, $c, 1) <= 0) {
-            return $state->buf;
-        }
+        my $c = ReadKey(0) or return $state->buf;
         my $cc = ord($c);
 
         if ($cc == 9 && defined $self->{completion_callback}) {
@@ -193,6 +202,7 @@ sub edit {
         } elsif ($cc == 14) { # ctrl-n
             $self->edit_history_next($state, $HISTORY_NEXT);
         } elsif ($cc == 27) { # escape sequence
+            next if $IS_WIN32;
             # Read the next two bytes representing the escape sequence
             CORE::read(*STDIN, my $buf, 2)==2 or return undef;
             if ($buf eq "[D") { # left arrow
@@ -268,7 +278,7 @@ sub complete_line {
             $self->refresh_line($state);
         }
 
-        CORE::read(*STDIN, my $c, 1) ==1 or return undef;
+        my $c = ReadKey(0) or return undef;
         my $cc = ord($c);
         if ($cc == 9) { # tab
             $i = ($i+1) % (1+@ret);
@@ -496,6 +506,7 @@ sub edit_insert {
 
 sub is_supported {
     my ($self) = @_;
+    return 1 if $IS_WIN32;
     my $term = $ENV{'TERM'};
     return 0 unless defined $term;
     return 0 if $term eq 'dumb';
@@ -568,8 +579,16 @@ This module supports
 
 =item Complition
 
+=item Portable
+
+=item No C library dependency
+
 =back
 
+=head1 PROJECT GOALS
+
+Provides portable line editing library for Perl5 community.
+
 =head1 METHODS
 
 =over 4
@@ -645,8 +664,6 @@ it under the same terms as Perl itself.
 
 =over 4
 
-=item Win32 Support
-
 =item Search with C-r
 
 =back
